#!/usr/bin/python
#
# Parses the text files available from the ??utlzd.zip files available at:
#    http://www.nanpa.com/number_resource_info/co_code_assignments1.html
#

import string
import sys


def get_columns(s):
    """
    Returns a list of pairs of (name,start,length) for all of the columns
    in a string.
    """
    cols = []
    inword = 0
    cp = 0          # current position
    cstart = -1
    cname  = ""
    for c in s:
        if (not inword and (c not in string.whitespace)):   # start a column
            if cstart >= 0:
                cols.append((string.strip(cname), cstart, cp-cstart))
            inword = 1
            cstart = cp
            try:
                (cname, rest) = string.split(s[cp:], " ", 1)
            except ValueError:
                cname = s[cp:]
            cname = string.translate(cname, string.maketrans('-/', '__'))
        elif (c in string.whitespace):
            inword = 0        
        cp = cp + 1
    if cstart:
        cols.append((cname, cstart, cp-cstart))
    return cols

def field_strip(s):
    s = string.strip(s)
    if not s: return ""
    if s[0] == '"':
        s = s[1:]
    if s[-1] == '"':
        s = s[:-1]
    s = string.strip(s)
    return s

class NanpaRow:

    def __init__(self, hash):
        self.data = hash

    def __getattr__(self, an):
        if not self.data.has_key(an): return ""
        else: return self.data[an]

    def summary(self):
        "Returns summary string (not including NPA_NXX info"
        r = self
        s = "%s, %s (%s) %s"%(r.RateCenter, r.State, r.Switch, r.Company)
        extra = ""
        if self.OCN:
            extra = extra+" ocn:"+r.OCN
        if self.Use:
            extra = extra+" use:"+r.Use+self.expand_use()
        if self.EffectiveDate:
            extra = extra+" effective:"+r.EffectiveDate
        if self.AssignDate: extra = extra+" assigned:"+r.AssignDate
        if self.Initial_Growth == "I":
            extra = extra+" initial"
        elif self.Initial_Growth == "I":
            extra = extra+" growth"
        if extra:
            s = s + " /" + extra
        return s

    def expand_use(self):
        use = self.Use
        if (use == "VC"): return "(vacant)"
        elif (use == "AS"): return "(assigned)"
        elif (use == "PR"): return "(protected-for-split)"
        elif (use == "RV"): return "(reserved)"
        elif (use == "UA"): return "(unavailable)"
        else: return ""
        
class Nanpa:

    def __init__(self, file = sys.stdin):
        fp = file
        header = string.expandtabs(fp.readline())
        self.cols = get_columns(header)
        print self.cols
        self.rows = []
        x = fp.readline()
        curline = 0
        while x:
            x = string.expandtabs(x)
            row = {}
            for col in self.cols:
                v = field_strip(x[col[1]:col[1]+col[2]])
                if v: 
                    row[col[0]] = v
            if row:
                self.rows.append(NanpaRow(row))
            x = fp.readline()
            
            if not (curline%1000): print "#line %s"%(curline)
            curline = curline + 1

    def get_rows(self):
        return self.rows


#print "<%s>"%(field_strip("""  "CABLEVISION - CT                  "  """))
#print "<%s>"%(field_strip("""  CABLEVISION - CT                    """))

if (__name__ == "__main__"):
    if (len(sys.argv) > 1):
        fp = open(sys.argv[1])
        n = Nanpa(fp)
        fp.close()
    else:
        n = Nanpa(sys.stdin)
    for r in n.get_rows():
        print "%s %s"%(r.NPA_NXX, r.summary())

